@@ -41,6 +41,9 @@ FAILEDOPERATION_GETCVMSERVERFAILED = 'FailedOperation.GetCvmServerFailed'
 # 调去询价中心服务失败
 FAILEDOPERATION_GETTRADESERVERFAILED = 'FailedOperation.GetTradeServerFailed'
 
+# 不允许更多的扩缩容规则。
+FAILEDOPERATION_MORESTRATEGYNOTALLOWED = 'FailedOperation.MoreStrategyNotAllowed'
+
 # 操作失败，不支持pod。
 FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
 
@@ -80,12 +83,21 @@ INTERNALERROR_CONFIGCGWERROR = 'InternalError.ConfigCgwError'
 # 内部服务调用异常。
 INTERNALERROR_CVMERROR = 'InternalError.CvmError'
 
+# DB查询异常。
+INTERNALERROR_DBQUERYEXCEPTION = 'InternalError.DBQueryException'
+
+# 请求OpenTSDB异常。
+INTERNALERROR_DOOPENTSDBREQUESTEXCEPTION = 'InternalError.DoOpenTSDBRequestException'
+
 # 调用EKS报错。
 INTERNALERROR_EKSERROR = 'InternalError.EKSError'
 
 # 内部服务调用异常。
 INTERNALERROR_KMSERROR = 'InternalError.KmsError'
 
+# 请求OpenTSDB失败。
+INTERNALERROR_OPENTSDBHTTPRETURNCODENOTOK = 'InternalError.OpenTSDBHttpReturnCodeNotOK'
+
 # 内部服务调用异常。
 INTERNALERROR_PROJECTCGWERROR = 'InternalError.ProjectCgwError'
 
@@ -155,12 +167,24 @@ INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'
 # 参数错误。
 INVALIDPARAMETER_INVALIDCOMMONDISKTYPE = 'InvalidParameter.InvalidCommonDiskType'
 
+# 不合法的指标比较方法。
+INVALIDPARAMETER_INVALIDCOMPAREMETHOD = 'InvalidParameter.InvalidCompareMethod'
+
 # 无效的组件。
 INVALIDPARAMETER_INVALIDCOMPONENT = 'InvalidParameter.InvalidComponent'
 
+# 至少需要一个触发条件。
+INVALIDPARAMETER_INVALIDCONDITIONNUM = 'InvalidParameter.InvalidConditionNum'
+
 # Core节点数量无效。
 INVALIDPARAMETER_INVALIDCORECOUNT = 'InvalidParameter.InvalidCoreCount'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDCOREDISKTYPE = 'InvalidParameter.InvalidCoreDiskType'
+
+# 无效的CosBucket
+INVALIDPARAMETER_INVALIDCOSBUCKET = 'InvalidParameter.InvalidCosBucket'
+
 # CosFileUri参数值无效。
 INVALIDPARAMETER_INVALIDCOSFILEURI = 'InvalidParameter.InvalidCosFileURI'
 
@@ -176,6 +200,9 @@ INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomized
 # DependService和EnableKerberos参数冲突。
 INVALIDPARAMETER_INVALIDDEPENDSERVICEANDENABLEKERBEROSCONFLICT = 'InvalidParameter.InvalidDependServiceAndEnableKerberosConflict'
 
+# 无效的磁盘数量。
+INVALIDPARAMETER_INVALIDDISKNUM = 'InvalidParameter.InvalidDiskNum'
+
 # 无效的磁盘大小。
 INVALIDPARAMETER_INVALIDDISKSIZE = 'InvalidParameter.InvalidDiskSize'
 
@@ -227,12 +254,18 @@ INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'
 # 变配规格无效。
 INVALIDPARAMETER_INVALIDMODIFYSPEC = 'InvalidParameter.InvalidModifySpec'
 
+# 不合法的节点数量。
+INVALIDPARAMETER_INVALIDNODECOUNT = 'InvalidParameter.InvalidNodeCount'
+
 # 不合法的节点类型。
 INVALIDPARAMETER_INVALIDNODEFLAG = 'InvalidParameter.InvalidNodeFlag'
 
 # 无效的NodeType。
 INVALIDPARAMETER_INVALIDNODETYPE = 'InvalidParameter.InvalidNodeType'
 
+# 无效的SoftInfo。
+INVALIDPARAMETER_INVALIDPARAMTERINVALIDSOFTINFO = 'InvalidParameter.InvalidParamterInvalidSoftInfo'
+
 # 无效密码。
 INVALIDPARAMETER_INVALIDPASSWORD = 'InvalidParameter.InvalidPassword'
 
@@ -242,6 +275,9 @@ INVALIDPARAMETER_INVALIDPAYMODE = 'InvalidParameter.InvalidPaymode'
 # 无效的引导操作脚本。
 INVALIDPARAMETER_INVALIDPREEXECUTEDFILE = 'InvalidParameter.InvalidPreExecutedFile'
 
+# 不合法的指标处理方法。
+INVALIDPARAMETER_INVALIDPROCESSMETHOD = 'InvalidParameter.InvalidProcessMethod'
+
 # 无效参数，不符合EMR版本。
 INVALIDPARAMETER_INVALIDPRODUCT = 'InvalidParameter.InvalidProduct'
 
@@ -263,6 +299,9 @@ INVALIDPARAMETER_INVALIDRESOURCEIDS = 'InvalidParameter.InvalidResourceIds'
 # 无效的资源规格。
 INVALIDPARAMETER_INVALIDRESOURCESPEC = 'InvalidParameter.InvalidResourceSpec'
 
+# 无效的扩缩容动作。
+INVALIDPARAMETER_INVALIDSCALEACTION = 'InvalidParameter.InvalidScaleAction'
+
 # 不合法的引导脚本执行参数。
 INVALIDPARAMETER_INVALIDSCRIPTBOOTSTRAPACTIONCONFIG = 'InvalidParameter.InvalidScriptBootstrapActionConfig'
 
@@ -296,6 +335,21 @@ INVALIDPARAMETER_INVALIDSOFTWAREVERSION = 'InvalidParameter.InvalidSoftWareVersi
 # invalid Parameter StartTime or EndTime.参数无效
 INVALIDPARAMETER_INVALIDSTARTTIMEORENDTIME = 'InvalidParameter.InvalidStartTimeOrEndTime'
 
+# invalid Parameter StatisticPeriod or TriggerThreshold.参数无效
+INVALIDPARAMETER_INVALIDSTATISTICPERIODORTRIGGERTHRESHOLD = 'InvalidParameter.InvalidStatisticPeriodOrTriggerThreshold'
+
+# 参数错误。
+INVALIDPARAMETER_INVALIDSTRATEGY = 'InvalidParameter.InvalidStrategy'
+
+# 无效的规则优先级。
+INVALIDPARAMETER_INVALIDSTRATEGYPRIORITY = 'InvalidParameter.InvalidStrategyPriority'
+
+# 无效的规格。
+INVALIDPARAMETER_INVALIDSTRATEGYSPEC = 'InvalidParameter.InvalidStrategySpec'
+
+# 不支持的扩缩容策略类型。
+INVALIDPARAMETER_INVALIDSTRATEGYTYPE = 'InvalidParameter.InvalidStrategyType'
+
 # 无效的子网ID。
 INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'
 
@@ -308,6 +362,9 @@ INVALIDPARAMETER_INVALIDTAGSGROUP = 'InvalidParameter.InvalidTagsGroup'
 # task的数量不能超过20。
 INVALIDPARAMETER_INVALIDTASKCOUNT = 'InvalidParameter.InvalidTaskCount'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDTIMELAYOUT = 'InvalidParameter.InvalidTimeLayout'
+
 # 无效的timespan。
 INVALIDPARAMETER_INVALIDTIMESPAN = 'InvalidParameter.InvalidTimeSpan'
 
@@ -317,6 +374,9 @@ INVALIDPARAMETER_INVALIDTIMEUNIT = 'InvalidParameter.InvalidTimeUnit'
 # 无效的Tke集群ID，或Tke集群不符合条件。
 INVALIDPARAMETER_INVALIDTKEINSTANCE = 'InvalidParameter.InvalidTkeInstance'
 
+# 父帐号uin参数输入异常。
+INVALIDPARAMETER_INVALIDUINNUM = 'InvalidParameter.InvalidUinNum'
+
 # 无效的统一元数据库。
 INVALIDPARAMETER_INVALIDUNIFYMETA = 'InvalidParameter.InvalidUnifyMeta'
 
@@ -341,6 +401,12 @@ INVALIDPARAMETER_PAYMODERESOURCENOTMATCH = 'InvalidParameter.PayModeResourceNotM
 # 项目与资源不匹配。
 INVALIDPARAMETER_PROJECTRESOURCENOTMATCH = 'InvalidParameter.ProjectResourceNotMatch'
 
+# 执行时间重复。
+INVALIDPARAMETER_REPEATEDEXECUTIONTIME = 'InvalidParameter.RepeatedExecutionTime'
+
+# 扩缩容规则名重复。
+INVALIDPARAMETER_REPEATEDSTRATEGYNAME = 'InvalidParameter.RepeatedStrategyName'
+
 # 存在无效的产品组件。
 INVALIDPARAMETER_SOFTWARENOTINPRODUCT = 'InvalidParameter.SoftwareNotInProduct'
 
@@ -377,6 +443,9 @@ RESOURCEINSUFFICIENT_DISKINSUFFICIENT = 'ResourceInsufficient.DiskInsufficient'
 # 不支持或售罄的节点规格。
 RESOURCEINSUFFICIENT_INSTANCEINSUFFICIENT = 'ResourceInsufficient.InstanceInsufficient'
 
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 资源不存在。
 RESOURCENOTFOUND_CDBINFONOTFOUND = 'ResourceNotFound.CDBInfoNotFound'
 
@@ -395,6 +464,9 @@ RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
 # 无法找到监控元数据。
 RESOURCENOTFOUND_RESOURCENOTFOUND = 'ResourceNotFound.ResourceNotFound'
 
+# 未找到相应扩缩容规则。
+RESOURCENOTFOUND_STRATEGYNOTFOUND = 'ResourceNotFound.StrategyNotFound'
+
 # 找不到对应的子网。
 RESOURCENOTFOUND_SUBNETNOTFOUND = 'ResourceNotFound.SubnetNotFound'
 
@@ -407,6 +479,9 @@ RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 # 当前资源规格不存在默认规格。
 RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
 
+# 资源规格不存在。
+RESOURCEUNAVAILABLE_RESOURCESPECNOTEXIST = 'ResourceUnavailable.ResourceSpecNotExist'
+
 # 资源售罄。
 RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
